:github_url: https://github.com/aetperf/Edsger

======
Edsger
======

*Graph algorithms in Cython*

Welcome to our Python library for graph algorithms. So far, the library only includes Dijkstra's algorithm but we should add a range of common path algorithms later. It is also open-source and easy to integrate with other Python libraries. To get started, simply install the library using pip, and import it into your Python project.

Installation
------------

The latest release of Edsger can be installed from
`PyPI <https://pypi.org/project/edsger/>`_ using::

   pip install edsger

You may also install directly from GitHub, using the following command. This
can be used to obtain the most recent version of Edsger::

   pip install 'edsger @ git+https://github.com/aetperf/Edsger'